import 'package:args/args.dart';
import 'package:comet_cli/cmd_create.dart';
import 'package:comet_cli/cmd_deploy.dart';
import 'package:comet_cli/run_help.dart';
import 'package:comet_cli/run_version.dart';

Future<void> cmdRoot(List<String> arguments) async {
  final parser = ArgParser();
  // --help, -h を登録
  parser.addFlag('help', abbr: 'h', help: 'Show usage information');
  // --version, -v を登録
  parser.addFlag('version', abbr: 'v', help: 'Show version number');

  // サブコマンド deploy を登録
  final deployParser = parser.addCommand('deploy');
  // deploy に --help, -h を登録
  deployParser.addFlag('help', abbr: 'h', help: 'Show usage information');

  // サブコマンド create を登録
  final createParser = parser.addCommand('create');
  // create に --help, -h を登録
  createParser.addFlag('help', abbr: 'h', help: 'Show usage information');

  /* START PARSE */

  final argsMap = parser.parse(arguments);

  final showHelp = argsMap['help'] as bool;
  if (showHelp) {
    runHelp();
    return;
  }
  final showVersion = argsMap['version'] as bool;
  if (showVersion) {
    runVersion();
    return;
  }

  final subCommand = argsMap.command;
  if (subCommand == null) {
    // サブコマンドがなければここで終了
    return;
  }

  switch (subCommand.name) {
    case 'deploy':
      cmdDeploy(deployParser, subCommand.arguments);
      break;
    case 'create':
      cmdCreate(createParser, subCommand.arguments);
      break;
    default:
      break;
  }
}
