import 'package:git/git.dart';
import 'package:path/path.dart' as path;

class GHPages {
  final String branch = 'gh-pages';
  late final GitDir gitDir;

  Future<void> updateBranch() async {
    gitDir = await GitDir.fromExisting(
      path.current,
      allowSubdirectory: true,
    );
    final indexPath = 'build/web';
    final indexDir = path.join(path.current, indexPath);
    final commitMsg = 'Deploy on ${DateTime.now().toIso8601String()}';
    await gitDir.updateBranchWithDirectoryContents(
      branch,
      indexDir,
      commitMsg,
    );
    print('FINISHED SUCCESSFULLY');
  }

  Future<void> publish({
    String remote = 'origin',
  }) async {
    final remoteExists = await _hasRemotes();
    if (!remoteExists) {
      print('No remotes.');
      throw Exception(
        'Current git directory has no remotes.',
      );
    }
    await gitDir.runCommand(['push', remote, branch]);
  }

  Future<bool> _hasRemotes() async {
    final result = await gitDir.runCommand(['remote']);
    if (result.exitCode != 0) {
      print('no remotes.');
      throw Exception('Could not list remotes.');
    }
    if (result.stdout is! String) {
      print('Invalid result for git remote command.');
      throw Exception(
        "Invalid result for 'git remote' command.",
      );
    }
    final remotes = result.stdout as String;
    return remotes.isNotEmpty;
  }
}
