import 'dart:io';
import 'package:archive/archive.dart';
import 'package:comet_cli/config.dart';

Future<void> unzipTemplate(List<int> bytes, String outputFolderName) async {
  // bytes --> zip
  final decoder = ZipDecoder();
  final archive = decoder.decodeBytes(bytes);

  // 既存のファイルやフォルダが存在するか確認
  final outputFolder = Directory(outputFolderName);
  final outputFolderIsAlreadyExists = outputFolder.existsSync();
  if (outputFolderIsAlreadyExists) {
    print('エラー: 出力ディレクトリが既に存在します。プログラムを停止します。');
    return;
  }

  // zip to nodes
  for (var node in archive) {
    // skip __MACOSX
    final skip = node.name.startsWith('__MACOSX/');
    if (skip) continue;

    final nodePath = node.name.replaceFirst(templateName, outputFolderName);
    if (node.isFile) {
      // file
      final file = File(nodePath);
      file.createSync(recursive: true);
      file.writeAsBytesSync(node.content as List<int>);
    } else {
      // folder
      final folder = Directory(nodePath);
      folder.create(recursive: true);
    }
  }
}
